Diff-based comparison of two crawl results.
Detects added/removed pages, status changes, title changes, content changes, and Core Web Vitals regressions between crawls.
Structs
- Crawl
Diff - Result of comparing two crawl databases.
- CwvChange
- A Core Web Vitals regression or improvement between crawls.
- Diff
Entry - A single diff entry.
Enums
- Change
Kind - The type of change detected for a page.
- Compare
Error - Errors specific to comparison operations.
Functions
- compare_
crawl_ ids - Compare two specific crawl IDs within the same or different databases.
- compare_
crawls - Compare two SQLite crawl databases by their latest crawl.
- diff_
to_ json - Write a diff to JSON.
- diff_
to_ markdown - Write a diff to Markdown.